..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Summary
-------

In this chapter we have looked at the tree data structure,
which enables us to write many interesting algorithms.
We have looked at algorithms that use various kinds of trees to do the following:

-  A binary tree for parsing and evaluating expressions.

-  A binary tree for implementing the map ADT.

-  A balanced binary tree (AVL tree) for implementing the map ADT.

-  A binary tree to implement a min heap.

-  A min heap used to implement a priority queue.

